# aiyt

> Transcribe, Chat and Summarize Youtube Video with AI

## 📺 Demo

[![demo-thumb]][demo]

## 📦 Usage

- run with `uvx`

```bash
uvx aiyt
```

- install locally

```bash
uv tool install aiyt

# then run it
aiyt
```

- upgrade to the lastest version

```bash
uvx aiyt@latest

# upgrade installed tool
uv tool upgrade aiyt@latest
```

- pre-fill API key

```bash
# export API key as environment variable
export GOOGLE_API_KEY=your-api-key

# or set API key in the command directly
GOOGLE_API_KEY=your-api-key uvx aiyt
```

## 💬 Questions

- [Github issue]
- [LinkedIn]

[demo-thumb]: https://raw.githubusercontent.com/hoishing/aiyt/main/youtube-thumbnail.webp
[demo]: https://www.youtube.com/watch?v=RMkSsaQzM64
[Github issue]: https://github.com/hoishing/aiyt/issues
[LinkedIn]: https://www.linkedin.com/in/kng2
